@@ -27,7 +27,7 @@ use autodie;
 use constant NUMPY_STRING => 'module compiled against ABI version %x'
   . ' but this version of numpy is %x';
 
-use Lintian::Check qw(check_spelling);
+use Lintian::Check qw(check_spelling spelling_tag_emitter);
 use Lintian::Data;
 use Lintian::Relation qw(:constants);
 use Lintian::Tags qw(tag);
@@ -123,12 +123,17 @@ sub run {
         my $objdump = $info->objdump_info->{$file};
         my $has_lfs;
         my $is_profiled = 0;
-        # Only 32bit ELF binaries can lack LFS.
-        $ARCH_32_REGEX = $ARCH_REGEX->value('32')
-          unless defined $ARCH_32_REGEX;
-        $has_lfs = 1 unless $info->file_info($file) =~ m/$ARCH_32_REGEX/o;
-        # We don't care if it is a debug file
-        $has_lfs = 1 if $file =~ m,^usr/lib/debug/,;
+
+        # The LFS check only works reliably for ELF files due to the
+        # architecture regex.
+        if ($objdump->{'ELF'}) {
+            # Only 32bit ELF binaries can lack LFS.
+            $ARCH_32_REGEX = $ARCH_REGEX->value('32')
+              unless defined $ARCH_32_REGEX;
+            $has_lfs = 1 unless $info->file_info($file) =~ m/$ARCH_32_REGEX/o;
+            # We don't care if it is a debug file
+            $has_lfs = 1 if $file =~ m,^usr/lib/debug/,;
+        }
 
         if (defined $objdump->{SONAME}) {
             foreach my $soname (@{$objdump->{SONAME}}) {
@@ -164,7 +169,6 @@ sub run {
             tag 'binary-compiled-with-profiling-enabled', $file
               if $is_profiled;
         }
-        tag 'binary-file-compressed-with-upx', $file if $objdump->{'UPX'};
         tag 'apparently-corrupted-elf-binary', $file
           if $objdump->{'ERRORS'};
         tag 'binary-file-built-without-LFS-support', $file
@@ -220,6 +224,7 @@ sub run {
     $base_pkg =~ s/c2a?\b//o;
     $base_pkg =~ s/\dg$//o;
     $base_pkg =~ s/gf$//o;
+    $base_pkg =~ s/v5$//o; # GCC-5 / libstdc++6 C11 ABI breakage
     $base_pkg =~ s/-udeb$//o;
     $base_pkg =~ s/^lib64/lib/o;
 
@@ -268,8 +273,6 @@ sub run {
           unless ($fileinfo =~ m/^[^,]*\bELF\b/)
           or ($fileinfo =~ m/\bcurrent ar archive\b/);
 
-        $objdump = $info->objdump_info->{$file};
-
         # Warn about Architecture: all packages that contain shared libraries.
         if ($arch eq 'all') {
             tag 'arch-independent-package-contains-binary-or-object',$file;
@@ -290,6 +293,23 @@ sub run {
                 tag 'arch-dependent-file-not-in-arch-specific-directory',$file;
             }
         }
+        if ($fileinfo =~ m/\bcurrent ar archive\b/) {
+
+            # "libfoo_g.a" is usually a "debug" library, so ignore
+            # unneeded sections in those.
+            next if $file =~ m/_g\.a$/;
+
+            $objdump = $info->objdump_info->{$file};
+
+            foreach my $obj (@{ $objdump->{'objects'} }) {
+                my $libobj = $info->objdump_info->{"${file}(${obj})"};
+                # Shouldn't happen, but...
+                fail("object ($file $obj) in static lib is missing!?")
+                  unless defined $libobj;
+                tag_unneeded_sections('static-library-has-unneeded-section',
+                    "${file}(${obj})", $libobj);
+            }
+        }
 
         # ELF?
         next unless $fileinfo =~ m/^[^,]*\bELF\b/o;
@@ -331,7 +351,9 @@ sub run {
             'tEH' => 1, # From #782902
             'tEh' => 1, # From #782902, too
         };
-        check_spelling('spelling-error-in-binary',$strings, $file,$exceptions);
+        my $tag_emitter
+          = spelling_tag_emitter('spelling-error-in-binary', $file);
+        check_spelling($strings, $exceptions, $tag_emitter);
 
         # stripped?
         if ($fileinfo =~ m,\bnot stripped\b,o) {
@@ -357,11 +379,8 @@ sub run {
                 tag 'library-in-debug-or-profile-should-not-be-stripped',$file;
             } else {
                 # appropriately stripped, but is it stripped enough?
-                foreach my $sect ('.note', '.comment') {
-                    if (exists $objdump->{'SH'}->{$sect}) {
-                        tag 'binary-has-unneeded-section', $file, $sect;
-                    }
-                }
+                tag_unneeded_sections('binary-has-unneeded-section', $file,
+                    $objdump);
             }
         }
 
@@ -593,6 +612,16 @@ sub run {
     return;
 }
 
+sub tag_unneeded_sections {
+    my ($tag, $file, $objdump) = @_;
+    foreach my $sect ('.note', '.comment') {
+        if (exists $objdump->{'SH'}->{$sect}) {
+            tag $tag, "$file $sect";
+        }
+    }
+    return;
+}
+
 1;
 
 # Local Variables:
