@@ -32,7 +32,7 @@ use v5.10;
 # Half of the size used in the "sliding window" for detecting bad
 # licenses like GFDL with invariant sections.
 # NB: Keep in sync cruft-gfdl-fp-sliding-win/pre_build.
-use constant BLOCKSIZE => 4096;
+use constant BLOCKSIZE => 16_384;
 
 use Lintian::Data;
 use Lintian::Relation ();
@@ -641,6 +641,16 @@ sub find_cruft {
             close($fd);
         }
 
+        # Lena Söderberg image
+        if ($basename =~ /\blenn?a\b/i) {
+            if(    $file_info =~ /\bimage\b/i
+                or $file_info =~ /^Matlab v\d+ mat/i
+                or $file_info =~ /\bbitmap\b/i) {
+                tag 'license-problem-non-free-img-lenna', $name;
+            }
+
+        }
+
         # here we check old upstream specification
         # debian/upstream should be a directory
         if (   $name eq 'debian/upstream'
@@ -799,7 +809,7 @@ sub full_text_check {
     }
 
     my $fd = $entry->open(':raw');
-    # allow to check only text file
+    # check only text files
     unless (-T $fd) {
         close($fd);
         return;
@@ -880,9 +890,15 @@ sub _search_in_block0 {
                 return;
             }
         }
+        # false positive in dx package at least
+        elsif($basename eq 'srchidx.js') {
+            if($block =~ m/\A\s*profiles \s* = \s* new \s* Array\s*\(/xms) {
+                return;
+            }
+        }
         # see #745152
         # Be robust check also .js
-        if($basename eq 'deployJava.js') {
+        elsif($basename eq 'deployJava.js') {
             if($block =~ m/(?:\A|\v)\s*var\s+deployJava\s*=\s*function/xmsi) {
                 check_missing_source($entry,$info,$name,$basename,$dirname,
                     [['(?i)\.js$','.txt'],['','']]);
@@ -1094,12 +1110,13 @@ sub _clean_block {
     # po comment may include html tag
     $text =~ s/\"\s?\v\#~\s?\"//gxms;
 
-    $text =~ s/\\url{[^}]*?}/ /gxms;          # (la)?tex url
-    $text =~ s/\\emph{/ /gxms;                # (la)?tex emph
-    $text =~ s/\\href{[^}]*?}
-                     {([^}]*?)}/ $1 /gxms;    # (la)?tex href
+    $text =~ s/\\url[{][^}]*?[}]/ /gxms;      # (la)?tex url
+    $text =~ s/\\emph[{]/ /gxms;              # (la)?tex emph
+    $text =~ s/\\href[{][^}]*?[}]
+                     [{]([^}]*?)[}]/ $1 /gxms;# (la)?tex href
     $text =~ s/\\hyperlink
-                 {[^}]*?}{([^}]*?)}/ $1 /gxms;# (la)?tex hyperlink
+                 [{][^}]*?[}]
+                 [{]([^}]*?)[}]/ $1 /gxms;    # (la)?tex hyperlink
     $text =~ s,-\\/,-,gxms;                   # tex strange hyphen
     $text =~ s,\\char, ,gxms;                 # tex  char command
 
@@ -1112,10 +1129,10 @@ sub _clean_block {
     $text =~ s/\@c(?:omment)?\s+/ /gxms;      # Tex info comment
 
     # Tex info bold,italic, roman, fixed width
-    $text =~ s/\@[birt]{/ /gxms;
-    $text =~ s/\@sansserif{/ /gxms;           # Tex info sans serif
-    $text =~ s/\@slanted{/ /gxms;             # Tex info slanted
-    $text =~ s/\@var{/ /gxms;                 # Tex info emphasis
+    $text =~ s/\@[birt][{]/ /gxms;
+    $text =~ s/\@sansserif[{]/ /gxms;         # Tex info sans serif
+    $text =~ s/\@slanted[{]/ /gxms;             # Tex info slanted
+    $text =~ s/\@var[{]/ /gxms;                 # Tex info emphasis
 
     $text =~ s/\@(?:small)?example\s+/ /gxms; # Tex info example
     $text =~ s/\@end \h+
