@@ -311,7 +311,7 @@ sub run {
                 my $rc = $1;
                 my $rest = $2//'';
                 my $suggestion;
-                # Remove the rc-part and the preceeding symbol (if any).
+                # Remove the rc-part and the preceding symbol (if any).
                 $expected =~ s/[\.\+\-\:]?\Q$rc\E.*//;
                 $suggestion = "$expected~$rc$rest";
                 tag 'rc-version-greater-than-expected-version', $upstream, '>',
@@ -435,6 +435,11 @@ sub run {
             unfold($f, \$maintainer);
 
             if ($f eq 'uploaders') {
+                # check for empty field see  #783628
+                if($maintainer =~ m/,\s*,/) {
+                    tag 'uploader-name-missing','you have used a double comma';
+                    $maintainer =~ s/,\s*,/,/g;
+                }
                 my %duplicate_uploaders;
                 my @uploaders = map { split /\@\S+\K\s*,\s*/ }
                   split />\K\s*,\s*/, $maintainer;
