@@ -74,7 +74,7 @@ my $PRIVACY_BREAKER_TAG_ATTR= Lintian::Data->new(
     qr/\s*\~\~\s*/o,
     sub {
         my ($keywords,$regex) = split(/\s*\~\~\s*/, $_[1], 2);
-        $regex =~ s/&URL/(?:ht|f)tps?:\/\/[^"\r\n]*/g;
+        $regex =~ s/&URL/(?:(?:ht|f)tps?:)?\/\/[^"\r\n]*/g;
         my @keywordlist;
         my @keywordsorraw = split(/\s*\|\|\s*/,$keywords);
         foreach my $keywordor (@keywordsorraw) {
@@ -116,7 +116,7 @@ my $VCS_FILES = Lintian::Data->new(
     qr/\s++/,
     sub {
         my $regexp = $_[0];
-        $regexp =~ s/\${COMPRESS_EXT}/$COMPRESS_FILE_EXTENSIONS_OR_ALL/g;
+        $regexp =~ s/\$[{]COMPRESS_EXT[}]/$COMPRESS_FILE_EXTENSIONS_OR_ALL/g;
         return qr/(?:$regexp)/x;
     });
 
@@ -277,6 +277,18 @@ sub run {
     my $isma_same = $info->field('multi-arch', '') eq 'same';
     my $ppkg = quotemeta($pkg);
 
+    # get the last changelog timestamp
+    # if for some weird reasons the timestamp does
+    # not exist, it will remain 0
+    my $changes = $info->changelog;
+    my $changelog_timestamp = 0;
+    if (defined $changes) {
+        my ($entry) = $changes->data;
+        if ($entry && $entry->Timestamp) {
+            $changelog_timestamp = $entry->Timestamp;
+        }
+    }
+
     # find out which files are scripts
     my %script = map {$_ => 1} (sort keys %{$info->scripts});
 
@@ -414,10 +426,38 @@ sub run {
             }
         }
 
+        # see #785662
+        if($file->is_regular_file) {
+            if(index($fname,'oui') > -1 || index($fname,'iab') > -1) {
+                if($fname
+                    =~ m,/(?:[^/]-)?(?:oui|iab)(?:\.(txt|idx|db))?(?:\.$COMPRESS_FILE_EXTENSIONS_OR_ALL)?\Z,x
+                  ) {
+                    unless ($source_pkg eq 'ieee-data') {
+                        tag 'package-install-ieee-data', $file;
+                    }
+                }
+            }
+        }
+
         # ---------------- /etc
         if ($fname =~ m,^etc/,) {
+            # /etc/apt
+            if ($fname =~ m,^etc/apt/,) {
+                # -----------------/etc/apt/preferences
+                if ($fname =~ m,^etc/apt/preferences(?:\.d/)?,) {
+                    unless ($source_pkg eq 'apt') {
+                        tag 'package-install-apt-preferences', $file;
+                    }
+                }
+                # -----------------/etc/apt/sources
+                if ($fname =~ m,^etc/apt/sources(?:\.d/)?,) {
+                    unless ($source_pkg eq 'apt') {
+                        tag 'package-install-apt-sources', $file;
+                    }
+                }
+            }
             # ---------------- /etc/cron.daily, etc.
-            if ($fname
+            elsif ($fname
                 =~ m,^etc/cron\.(?:daily|hourly|monthly|weekly|d)/[^\.].*[\+\.],
               ) {
                 # NB: cron ships ".placeholder" files, which shouldn't be run.
@@ -692,6 +732,21 @@ sub run {
                 $fname=~ m,^usr/share/applications/mimeinfo.cache(?:\.gz)?$,){
                 tag 'package-contains-mimeinfo.cache-file', $file;
             }
+            # ---------------- /usr/share/cmake-*
+            elsif ($fname=~ m,^usr/share/cmake-\d+\.\d+/.+,){
+                unless ($source_pkg eq 'cmake') {
+                    tag 'package-contains-cmake-private-file', $file;
+                }
+            }
+            # ---------------- /usr/share/mime/
+            elsif ($fname=~ m,^usr/share/mime/.+,) {
+                # ---------------- /usr/share/mime
+                if ($fname =~ m,^usr/share/mime/[^/]+$,) {
+                    tag 'package-contains-mime-cache-file', $file;
+                }elsif ($fname!~ m,^usr/share/mime/packages/,) {
+                    tag 'package-contains-mime-file-outside-package-dir',$file;
+                }
+            }
             # ---------------- /usr/share/man and /usr/X11R6/man
             elsif ($fname =~ m,^usr/X11R6/man/\S+,
                 or $fname =~ m,^usr/share/man/\S+,) {
@@ -733,10 +788,6 @@ sub run {
             elsif ($fname =~ m,^usr/share/linda/overrides/\S+,) {
                 tag 'package-contains-linda-override', $file;
             }
-            # ---------------- /usr/share/mime
-            elsif ($fname =~ m,^usr/share/mime/[^/]+$,) {
-                tag 'package-contains-mime-cache-file', $file;
-            }
             # ---------------- /usr/share/p11-kit/modules
             elsif (
                    $fname =~ m{^usr/share/p11-kit/modules/.}
@@ -1097,7 +1148,7 @@ sub run {
             and not $fname =~ m{ \. (?:
                   # Common "non-license" file extensions...
                    el|[ch]|py|cc|pl|pm|hi|p_hi|html|php|rb|xpm
-                  |png|jpe?g|gif|svg|dtd|ui|pc
+                  |png|jpe?g|gif|svg|dtd|ui|pc|mk|lisp
                ) \Z}xsm
             and not $fname=~ m,^usr/share/zope/Products/.*\.(?:dtml|pt|cpt)$,
             and not $fname =~ m,/under\S+License\.docbook$,
@@ -1106,6 +1157,13 @@ sub run {
             and not $fname =~ m,^usr/share/man/(?:[^/]+/)?man\d/,o
             # liblicense (again)
             and not $fname =~ m,^usr/share/pyshared-data/,o
+            # Some GNOME/GTK software uses these to show the "license
+            # header".
+            and not $fname =~ m,
+               ^usr/share/(?:gnome/)?help/[^/]+/[^/]+/license\.page$
+             ,x
+            # base-files (which is required to ship them)
+            and not $fname =~ m,^usr/share/common-licenses/[^/]+$,o
             and not defined $link
           ) {
 
@@ -1311,7 +1369,12 @@ sub run {
 
             # ---------------- html/javascript
             if ($fname =~ m,\.(?:x?html?|js|xht|xml|css)$,i) {
-                detect_privacy_breach($info,$file);
+                if(     $source_pkg eq 'josm'
+                    and $file->basename eq 'defaultpresets.xml') {
+                    # false positive
+                } else {
+                    detect_privacy_breach($info,$file);
+                }
             }
             # ---------------- fonts
             elsif ($fname =~ m,/([\w-]+\.(?:[to]tf|pfb))$,i) {
@@ -1433,7 +1496,11 @@ sub run {
                         if ($isma_same && $file !~ m/\Q$arch\E/o) {
                             tag 'gzip-file-is-not-multi-arch-same-safe', $file;
                         } else {
-                            tag 'package-contains-timestamped-gzip', $file;
+                            # see https://bugs.debian.org/762105
+                            my $diff = $file->timestamp - $changelog_timestamp;
+                            if ($diff >= 0) {
+                                tag 'package-contains-timestamped-gzip', $file;
+                            }
                         }
                     }
                 }
@@ -1543,6 +1610,10 @@ sub run {
         }
         # ---------------- directories
         elsif ($file->is_dir) {
+            if ($file->faux) {
+                tag 'missing-intermediate-directory', $file;
+            }
+
             # special cases first:
             # game directory with setgid bit
             if (    $fname =~ m,^var/(?:lib/)?games/\S+,
@@ -1848,7 +1919,8 @@ sub is_localhost {
 sub _check_tag_url_privacy_breach {
     my ($fulltag, $tagattr, $url,$privacybreachhash, $file) = @_;
     my $website = $url;
-    $website =~ s,^"?(?:ht|f)tps?://,,;
+    # detect also "^//" trick
+    $website =~ s,^"?(?:(?:ht|f)tps?:)?//,,;
     $website =~ s/"?$//;
 
     if (is_localhost($website)){
@@ -1985,14 +2057,19 @@ sub detect_privacy_breach {
         }
         if(   index($block,'src="http') > -1
             ||index($block,'src="ftp') > -1
+            ||index($block,'src="//') > -1
             ||index($block,'data-href="http') > -1
             ||index($block,'data-href="ftp') > -1
+            ||index($block,'data-href="//') > -1
             ||index($block,'codebase="http') > -1
             ||index($block,'codebase="ftp') > -1
+            ||index($block,'codebase="//') > -1
             ||index($block,'data="http') > -1
             ||index($block,'data="ftp') > -1
+            ||index($block,'data="//') > -1
             ||index($block,'poster="http') > -1
             ||index($block,'poster="ftp') > -1
+            ||index($block,'poster="//') > -1
             ||index($block,'<link') > -1
             ||index($block,'@import') > -1){
             detect_generic_privacy_breach($block,\%privacybreachhash,$file);
