@@ -98,7 +98,7 @@ my $BAD_MAINT_CMD = Lintian::Data->new(
             fail 'Syntax error in scripts/maintainer-script-bad-command:', $.;
         }
         my ($incat,$exceptinpackage,$inscript,$regexp) = @sliptline;
-        $regexp =~ s/\${LEADIN}/$LEADINSTR/;
+        $regexp =~ s/\$[{]LEADIN[}]/$LEADINSTR/;
    # allow empty $exceptinpackage and set it synonymous to check in all package
         $exceptinpackage
           = defined($exceptinpackage) ? strip($exceptinpackage) : '';
@@ -757,7 +757,7 @@ sub run {
 
                     # Remove single quoted strings, with the exception
                     # that we don't remove the string
-                    # if the quote is immediately preceeded by a < or
+                    # if the quote is immediately preceded by a < or
                     # a -, so we can match "foo <<-?'xyz'" as a
                     # heredoc later The check is a little more greedy
                     # than we'd like, but the heredoc test itself will
@@ -914,7 +914,7 @@ sub run {
                 }
                 my $mode = /--remove/ ? 'remove' : 'add';
                 my ($divert) = /dpkg-divert\s*(.*)$/;
-                $divert =~ s{\s*(?:\${?[\w:=-]+}?)*\s*
+                $divert =~ s{\s*(?:\$[{]?[\w:=-]+[}]?)*\s*
                                 # options without arguments
                               --(?:add|quiet|remove|rename|test|local
                                 # options with arguments
@@ -950,7 +950,8 @@ sub run {
 
                 # For now just replace variables, they will later be normalised
                 $expand_diversions = 1 if $divert =~ s/\\\$\w+/.+/g;
-                $expand_diversions = 1 if $divert =~ s/\\\$\\{\w+.*?\\}/.+/g;
+                $expand_diversions = 1
+                  if $divert =~ s/\\\$\\[{]\w+.*?\\[}]/.+/g;
                 # handle $() the same way:
                 $expand_diversions = 1 if $divert =~ s/\\\$\\\(.+?\\\)/.+/g;
 
