@@ -361,6 +361,7 @@ sub objdump_info {
         my %info = (
             'PH' => {},
             'SH' => {},
+            'ELF'    => 1,
             'NOTES'  => [],
             'NEEDED' => [],
             'RPATH'  => {},
@@ -368,7 +369,6 @@ sub objdump_info {
             'TEXTREL' => 0,
         );
         $info{'ERRORS'} = lc($pg->{'broken'}//'no') eq 'yes' ? 1 : 0;
-        $info{'UPX'} = lc($pg->{'upx'}//'no') eq 'yes' ? 1 : 0;
         $info{'BAD-DYNAMIC-TABLE'}
           = lc($pg->{'bad-dynamic-table'}//'no') eq 'yes' ? 1 : 0;
         foreach my $symd (split m/\s*\n\s*/, $pg->{'dynamic-symbols'}//'') {
@@ -413,6 +413,25 @@ sub objdump_info {
             }
         }
 
+        if ($pg->{'filename'} =~ m,^(.+)\(([^/\)]+)\)$,o) {
+            # object file in a static lib.
+            my ($lib, $obj) = ($1, $2);
+            my $libentry = $objdump_info{$lib};
+            $info{'ELF'} = 0;
+            if (not defined $libentry) {
+                $libentry = {
+                    'filename' => $lib,
+                    'objects'  => [$obj],
+                    # static libs have no SONAMEs (and shared-libs
+                    # checks for it)
+                    'SONAME'   => [],
+                    'ELF'      => 0,
+                };
+                $objdump_info{$lib} = $libentry;
+            } else {
+                push @{ $libentry->{'objects'} }, $obj;
+            }
+        }
         $objdump_info{$pg->{'filename'}} = \%info;
     }
     $self->{objdump_info} = \%objdump_info;
@@ -648,6 +667,7 @@ Needs-Info requirements for using I<is_pkg_class>: L<Same as field|Lintian::Coll
             return;
         }
         return 1 if $desc =~ m/transitional package/;
+        $desc = lc($desc);
         if ($pkg_class eq 'any-meta') {
             my ($section) = $self->field('section', '');
             return 1 if $desc =~ m/$METAPKG_REGEX/o;
